[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

Bug#316108: marked as done (qt-x11-free: Please add gtkstyle patch)



Your message dated Wed, 07 Sep 2005 15:28:25 -0700
with message-id <E1ED8P3-0005EV-00@spohr.debian.org>
and subject line Bug#316108: fixed in qt-x11-free 3:3.3.4-8
has caused the attached Bug report to be marked as done.

This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.

(NB: If you are a system administrator and have no idea what I am
talking about this indicates a serious mail system misconfiguration
somewhere.  Please contact me immediately.)

Debian bug tracking system administrator
(administrator, Debian Bugs database)

--------------------------------------
Received: (at submit) by bugs.debian.org; 28 Jun 2005 14:31:28 +0000
>From henrich@debian.or.jp Tue Jun 28 07:31:28 2005
Return-path: <henrich@debian.or.jp>
Received: from c201166.ppp.asahi-net.or.jp (grapefruit) [210.155.201.166] 
	by spohr.debian.org with esmtp (Exim 3.35 1 (Debian))
	id 1DnH7X-0003gp-00; Tue, 28 Jun 2005 07:31:27 -0700
Received: by grapefruit (Postfix, from userid 1000)
	id 192AA40B9; Tue, 28 Jun 2005 23:33:05 +0900 (JST)
Content-Type: multipart/mixed; boundary="===============1472334394=="
MIME-Version: 1.0
From: Hideki Yamane <henrich@debian.or.jp>
To: Debian Bug Tracking System <submit@bugs.debian.org>
Subject: qt-x11-free: Please add gtkstyle patch
X-Mailer: reportbug 3.15
Date: Tue, 28 Jun 2005 23:33:04 +0900
Message-Id: <20050628143305.192AA40B9@grapefruit>
Delivered-To: submit@bugs.debian.org
X-Spam-Checker-Version: SpamAssassin 2.60-bugs.debian.org_2005_01_02 
	(1.212-2003-09-23-exp) on spohr.debian.org
X-Spam-Status: No, hits=-8.0 required=4.0 tests=BAYES_00,HAS_PACKAGE 
	autolearn=no version=2.60-bugs.debian.org_2005_01_02
X-Spam-Level: 

This is a multi-part MIME message sent by reportbug.

--===============1472334394==
Content-Type: text/plain; charset="us-ascii"
MIME-Version: 1.0
Content-Transfer-Encoding: 7bit
Content-Disposition: inline

Package: qt-x11-free
Severity: wishlist
Tags: patch

-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1

Dear qt-x11-free maintainer,

 This patch provides gtkstyle in QT, that is from fedora.
 I need this to make newest redhat-artwork package that includes
 bluecurve theme in gnome/kde.
 
 Could you apply it, please?

 You also can get it from
 http://cvs.fedora.redhat.com/viewcvs/devel/qt/qt-3.3.3-gtkstyle.patch.


- --
Regards,

 Hideki Yamane     henrich @ samba.gr.jp/debian.or.jp/iijmio-mail.jp



-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.1 (GNU/Linux)

iD8DBQFCwV+gIu0hy8THJksRAvlCAJ9KPfGAuaJShE0toT7Kx56j5ncpfQCgpIHK
9dM7Dfak9ssjTb46LIcGOHg=
=cy7e
-----END PGP SIGNATURE-----

--===============1472334394==
Content-Type: text/x-c++; charset="us-ascii"
MIME-Version: 1.0
Content-Transfer-Encoding: 7bit
Content-Disposition: attachment; filename="qt-3.3.3-gtkstyle.patch"

--- qt-x11-free-3.3.3.orig/src/widgets/qmenubar.cpp	2004-08-05 16:42:21.000000000 +0200
+++ qt-x11-free-3.3.3/src/widgets/qmenubar.cpp	2004-12-03 17:26:43.000000000 +0100
@@ -228,6 +228,10 @@
 static const int motifItemHMargin	= 5;	// menu item hor text margin
 static const int motifItemVMargin	= 4;	// menu item ver text margin
 
+// The others are 0
+static const int gtkItemHMargin = 8;
+static const int gtkItemVMargin = 8;
+
 /*
 
 +-----------------------------
@@ -292,7 +296,14 @@
     setFrameStyle( QFrame::MenuBarPanel | QFrame::Raised );
 
     QFontMetrics fm = fontMetrics();
-    int h = 2*motifBarVMargin + fm.height() + motifItemVMargin + 2*frameWidth() + 2*motifItemFrame;
+
+    int h;
+    int gs = style().styleHint(QStyle::SH_GUIStyle);
+    if (gs == GtkStyle) {
+        h = fm.height() + gtkItemVMargin;
+    } else {
+        h = 2*motifBarVMargin + fm.height() + motifItemVMargin + 2*frameWidth() + 2*motifItemFrame;
+    }
 
     setGeometry( 0, 0, width(), h );
 
@@ -944,12 +955,19 @@
 	    h = QMAX( mi->pixmap()->height() + 4, QApplication::globalStrut().height() );
 	} else if ( !mi->text().isNull() ) {	// text item
 	    QString s = mi->text();
-	    w = fm.boundingRect( s ).width()
-		+ 2*motifItemHMargin;
+        if ( gs == GtkStyle ) {
+            w = fm.boundingRect( s ).width() + 2*gtkItemHMargin;
+        } else {
+	        w = fm.boundingRect( s ).width() + 2*motifItemHMargin;
+        }
 	    w -= s.contains('&')*fm.width('&');
 	    w += s.contains("&&")*fm.width('&');
 	    w = QMAX( w, QApplication::globalStrut().width() );
-	    h = QMAX( fm.height() + motifItemVMargin, QApplication::globalStrut().height() );
+        if (gs == GtkStyle ) {
+            h = QMAX( fm.height() + gtkItemVMargin, QApplication::globalStrut().height() );
+        } else {
+	        h = QMAX( fm.height() + motifItemVMargin, QApplication::globalStrut().height() );
+        }
 	} else if ( mi->isSeparator() ) {	// separator item
 	    if ( style().styleHint(QStyle::SH_GUIStyle) == MotifStyle )
 		separator = i; //### only motif?
--- qt-x11-free-3.3.3.orig/src/widgets/qpopupmenu.cpp	2004-08-05 16:42:21.000000000 +0200
+++ qt-x11-free-3.3.3/src/widgets/qpopupmenu.cpp	2004-12-03 17:43:50.000000000 +0100
@@ -65,6 +65,8 @@
 static const int motifArrowHMargin	= 6;	// arrow horizontal margin
 static const int motifArrowVMargin	= 2;	// arrow vertical margin
 
+static const int gtkArrowHMargin	= 0;	// arrow horizontal margin
+static const int gtkArrowVMargin	= 0;	// arrow vertical margin
 
 /*
 
@@ -2290,8 +2292,18 @@
     QRect r( itemGeometry( actItem ) );
     QPoint p;
     QSize ps = popup->sizeHint();
+    // GUI Style
+    int gs = style().styleHint(QStyle::SH_GUIStyle);
+    int arrowHMargin, arrowVMargin;
+    if (gs == GtkStyle) {
+        arrowHMargin = gtkArrowHMargin;
+        arrowVMargin = gtkArrowVMargin;
+    } else {
+        arrowHMargin = motifArrowHMargin;
+        arrowVMargin = motifArrowVMargin;
+    }
     if( QApplication::reverseLayout() ) {
-	p = QPoint( r.left() + motifArrowHMargin - ps.width(), r.top() + motifArrowVMargin );
+	p = QPoint( r.left() + arrowHMargin - ps.width(), r.top() + arrowVMargin );
 	p = mapToGlobal( p );
 
 	bool right = FALSE;
@@ -2304,7 +2316,7 @@
 	if ( right )
 	    p.setX( mapToGlobal( r.topRight() ).x() );
     } else {
-	p = QPoint( r.right() - motifArrowHMargin, r.top() + motifArrowVMargin );
+	p = QPoint( r.right() - arrowHMargin, r.top() + arrowVMargin );
 	p = mapToGlobal( p );
 
 	bool left = FALSE;
--- qt-x11-free-3.3.3.orig/src/kernel/qnamespace.h	2004-08-05 16:42:10.000000000 +0200
+++ qt-x11-free-3.3.3/src/kernel/qnamespace.h	2004-11-29 22:22:26.000000000 +0100
@@ -294,7 +294,8 @@
 #ifdef QT_NO_COMPAT
     enum GUIStyle {
 	WindowsStyle = 1,     // ### Qt 4.0: either remove the obsolete enums or clean up compat vs.
-	MotifStyle = 4        // ### QT_NO_COMPAT by reordering or combination into one enum.
+	MotifStyle = 4,       // ### QT_NO_COMPAT by reordering or combination into one enum.
+    GtkStyle = 6          // Gtk compability mode
     };
 #else
     enum GUIStyle {
@@ -302,7 +303,8 @@
 	WindowsStyle,
 	Win3Style, // OBSOLETE
 	PMStyle, // OBSOLETE
-	MotifStyle
+	MotifStyle,
+    GtkStyle = 6          // Gtk compability mode
     };
 #endif
 

--===============1472334394==--

---------------------------------------
Received: (at 316108-close) by bugs.debian.org; 7 Sep 2005 22:38:31 +0000
>From joerg@spohr.debian.org Wed Sep 07 15:38:31 2005
Return-path: <joerg@spohr.debian.org>
Received: from joerg by spohr.debian.org with local (Exim 3.36 1 (Debian))
	id 1ED8P3-0005EV-00; Wed, 07 Sep 2005 15:28:25 -0700
From: Debian Qt/KDE Maintainers <debian-qt-kde@lists.debian.org>
To: 316108-close@bugs.debian.org
X-Katie: lisa $Revision: 1.30 $
Subject: Bug#316108: fixed in qt-x11-free 3:3.3.4-8
Message-Id: <E1ED8P3-0005EV-00@spohr.debian.org>
Sender: Joerg Jaspert <joerg@spohr.debian.org>
Date: Wed, 07 Sep 2005 15:28:25 -0700
Delivered-To: 316108-close@bugs.debian.org
X-Spam-Checker-Version: SpamAssassin 2.60-bugs.debian.org_2005_01_02 
	(1.212-2003-09-23-exp) on spohr.debian.org
X-Spam-Level: 
X-Spam-Status: No, hits=-6.0 required=4.0 tests=BAYES_00,HAS_BUG_NUMBER 
	autolearn=no version=2.60-bugs.debian.org_2005_01_02
X-CrossAssassin-Score: 8

Source: qt-x11-free
Source-Version: 3:3.3.4-8

We believe that the bug you reported is fixed in the latest version of
qt-x11-free, which is due to be installed in the Debian FTP archive:

libqt3-compat-headers_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/libqt3-compat-headers_3.3.4-8_i386.deb
libqt3-headers_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/libqt3-headers_3.3.4-8_i386.deb
libqt3-i18n_3.3.4-8_all.deb
  to pool/main/q/qt-x11-free/libqt3-i18n_3.3.4-8_all.deb
libqt3-mt-dbg_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/libqt3-mt-dbg_3.3.4-8_i386.deb
libqt3-mt-dev_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/libqt3-mt-dev_3.3.4-8_i386.deb
libqt3-mt-mysql_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/libqt3-mt-mysql_3.3.4-8_i386.deb
libqt3-mt-odbc_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/libqt3-mt-odbc_3.3.4-8_i386.deb
libqt3-mt-psql_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/libqt3-mt-psql_3.3.4-8_i386.deb
libqt3-mt-sqlite_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/libqt3-mt-sqlite_3.3.4-8_i386.deb
libqt3-mt_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/libqt3-mt_3.3.4-8_i386.deb
qt-x11-free_3.3.4-8.diff.gz
  to pool/main/q/qt-x11-free/qt-x11-free_3.3.4-8.diff.gz
qt-x11-free_3.3.4-8.dsc
  to pool/main/q/qt-x11-free/qt-x11-free_3.3.4-8.dsc
qt3-apps-dev_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/qt3-apps-dev_3.3.4-8_i386.deb
qt3-assistant_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/qt3-assistant_3.3.4-8_i386.deb
qt3-designer_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/qt3-designer_3.3.4-8_i386.deb
qt3-dev-tools-compat_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/qt3-dev-tools-compat_3.3.4-8_i386.deb
qt3-dev-tools-embedded_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/qt3-dev-tools-embedded_3.3.4-8_i386.deb
qt3-dev-tools_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/qt3-dev-tools_3.3.4-8_i386.deb
qt3-doc_3.3.4-8_all.deb
  to pool/main/q/qt-x11-free/qt3-doc_3.3.4-8_all.deb
qt3-examples_3.3.4-8_all.deb
  to pool/main/q/qt-x11-free/qt3-examples_3.3.4-8_all.deb
qt3-linguist_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/qt3-linguist_3.3.4-8_i386.deb
qt3-qtconfig_3.3.4-8_i386.deb
  to pool/main/q/qt-x11-free/qt3-qtconfig_3.3.4-8_i386.deb



A summary of the changes between this version and the previous one is
attached.

Thank you for reporting the bug, which will now be closed.  If you
have further comments please address them to 316108@bugs.debian.org,
and the maintainer will reopen the bug report if appropriate.

Debian distribution maintenance software
pp.
Debian Qt/KDE Maintainers <debian-qt-kde@lists.debian.org> (supplier of updated qt-x11-free package)

(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing ftpmaster@debian.org)


-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1

Format: 1.7
Date: Wed,  7 Sep 2005 11:23:55 -0400
Source: qt-x11-free
Binary: libqt3-i18n qt3-apps-dev libqt3-mt-sqlite qt3-assistant qt3-examples qt3-doc libqt3-headers libqt3-mt-mysql libqt3-mt libqt3-mt-dbg libqt3-mt-odbc qt3-dev-tools-embedded libqt3-compat-headers qt3-dev-tools libqt3-mt-ibase qt3-designer qt3-linguist qt3-qtconfig qt3-dev-tools-compat libqt3-mt-dev libqt3-mt-psql
Architecture: source i386 all
Version: 3:3.3.4-8
Distribution: unstable
Urgency: low
Maintainer: Debian Qt/KDE Maintainers <debian-qt-kde@lists.debian.org>
Changed-By: Debian Qt/KDE Maintainers <debian-qt-kde@lists.debian.org>
Description: 
 libqt3-compat-headers - Qt 1.x and 2.x compatibility includes
 libqt3-headers - Qt3 header files
 libqt3-i18n - i18n files for Qt3 library
 libqt3-mt  - Qt GUI Library (Threaded runtime version), Version 3
 libqt3-mt-dbg - debugging symbols for libqt3-mt
 libqt3-mt-dev - Qt development files (Threaded)
 libqt3-mt-mysql - MySQL database driver for Qt3 (Threaded)
 libqt3-mt-odbc - ODBC database driver for Qt3 (Threaded)
 libqt3-mt-psql - PostgreSQL database driver for Qt3 (Threaded)
 libqt3-mt-sqlite - SQLite database driver for Qt3 (Threaded)
 qt3-apps-dev - Qt3 Developer applications development files
 qt3-assistant - The Qt3 assistant application
 qt3-designer - Qt3 Designer
 qt3-dev-tools - Qt3 development tools
 qt3-dev-tools-compat - Conversion utilities for Qt3 development
 qt3-dev-tools-embedded - Tools to develop embedded Qt applications
 qt3-doc    - Qt3 API documentation
 qt3-examples - Examples for Qt3
 qt3-linguist - The Qt3 Linguist
 qt3-qtconfig - The Qt3 Configuration Application
Closes: 180326 185900 235396 284407 294630 296661 306879 316108 322868 326833 326990 327021
Changes: 
 qt-x11-free (3:3.3.4-8) unstable; urgency=low
 .
   +++ Changes by Christopher Martin:
 .
   * Add a patch fixing the generation of PostScript, which was broken due to
     a flaw in the code that only manifested itself with the GCC 4.0
     transition. This should fix printing in all Qt and KDE applications, as
     well as other glitches where nonsensical results were generated.
     (Closes: #326833, #326990, #327021)
 .
   * No longer build non-threaded libraries. (Closes: #180326)
     No package in the archive uses them, except a bogus qtdmm
     build-dependency (#326627).
 .
   * Add a libqt3c102-mt-dbg package. (Closes: #235396, #322868)
 .
   * Make the Qt3 documentation available from /usr/share/doc/qt3-doc, and
     therefore also usable in dwww and doc-central. (Closes: #185900, #284407,
     #294630)
 .
   * Apply packaging patches from Brian Nelson to allow Qt3 to co-exist
     with Qt4 packages. (Closes: #306879)
 .
   * Apply 06_disable_rpath to linux-g++-64/qmake.conf as too.
 .
   * Add the gtkstyle patch, in order to better support Bluecurve.
     (Closes: #316108)
 .
   * Add more patches from qt-copy:
     + 29_qtc_fix_rotated_randr: Improve height/width calculations for rotated
       screens.
     + 30_qtc_qtoolbar_77047: Fix for the toolbar extension menu.
     + 33_qtc_qlistbox-crash: Fixes a crash that shows up in KHTML.
     + 34_qtc_dnd_optimization: Massive DND speedups.
     + 35_qtc_dnd_active_window_fix: Fixes DND when windows are changing focus.
     + 36_qtc_dnd-timestamp-fix: Suppresses needless popups when using DND.
     + 37_qtc_dragobject-dont-prefer-unknown: Fixes DND with some apps, like
       Mozilla.
     + 38_qtc_khotkeys_input_84434: Fixes keyboard input action in KHotKeys.
     + 39_qtc_qpopup_has_mouse, 40_qtc_qpopup_ignore_mousepos: Fixes the mouse
       movement and position affecting keyboard navigation with popups and
       menus.
 .
   * Enable tablet support:
     - pass -tablet to configure.
     - add libxi-dev to Build-Depends.
 .
   * Build jpeg support into Qt, not as a plugin.
 .
   * Build the Qt styles as plugins. This does not affect the Qt buildkey,
     so shouldn't affect other packages.
 .
   * Revamp the OpenGL linking patch. This fixes the loading of libXmu, a
     problem which affected some screensavers. (Closes: #296661)
 .
   * Temporarily bump the libpq-dev build-depends to (>= 8.0.3-15), ensuring
     that we build against a version where the headers are located as expected.
Files: 
 ac32c36058dd9b02223a44fe11c2b1e1 1839 libs optional qt-x11-free_3.3.4-8.dsc
 c64508bf7c327fb0777e279df5004152 70181 libs optional qt-x11-free_3.3.4-8.diff.gz
 78bb925a1e55d69f830e19526baecead 94380 libs optional libqt3-i18n_3.3.4-8_all.deb
 396e202e67d07b3e0fd1192feafee2c8 8065132 doc extra qt3-doc_3.3.4-8_all.deb
 5cf7662538274d5f45a1778c4412266c 1554772 doc extra qt3-examples_3.3.4-8_all.deb
 7fa6fe3227b69403e304bc3548f54251 3207828 libs optional libqt3-mt_3.3.4-8_i386.deb
 dc996345b785f982dd5f2938be4149c7 17374958 libdevel extra libqt3-mt-dbg_3.3.4-8_i386.deb
 a788fa4bfae59844f8c5cd11c78738f0 51160 libs optional libqt3-mt-mysql_3.3.4-8_i386.deb
 b8633fc2504fae83d0412e9b33703c00 71330 libs optional libqt3-mt-odbc_3.3.4-8_i386.deb
 2c9d695edfb5cacb8c58a0fe76771cc7 57186 libs optional libqt3-mt-psql_3.3.4-8_i386.deb
 1b2384eb72dfd58ad9505cca35bb1a89 198688 libs optional libqt3-mt-sqlite_3.3.4-8_i386.deb
 05d30f9ad1de29b24ae9405dd8453849 49524 libdevel optional libqt3-mt-dev_3.3.4-8_i386.deb
 4f2abf1add1d28accd1b7b4af380475e 363828 devel optional libqt3-headers_3.3.4-8_i386.deb
 e1eb0ca1b66354060cdf6d7f907fe0f8 80896 devel optional libqt3-compat-headers_3.3.4-8_i386.deb
 e295ce5a720dfa56c83ee78c0127b39d 1257850 devel optional qt3-dev-tools_3.3.4-8_i386.deb
 29b1a2829ca6bc4a5d72bd92c18db6f2 1780408 devel optional qt3-designer_3.3.4-8_i386.deb
 40ab5e8bcd1f04662eba292d022859b8 2371656 devel optional qt3-apps-dev_3.3.4-8_i386.deb
 27d6fe9a8fcf567e176f5ce4aea023b0 270356 devel optional qt3-linguist_3.3.4-8_i386.deb
 013656df3bb9d0b19b0306b58a3474fa 235492 x11 optional qt3-assistant_3.3.4-8_i386.deb
 f98d0fb5570654d4f15ca160164d97f6 97042 x11 optional qt3-qtconfig_3.3.4-8_i386.deb
 e39f624588344958f849de4512ac2452 286374 devel optional qt3-dev-tools-embedded_3.3.4-8_i386.deb
 76fd3f8ba86d92b80d19a63566350499 69280 devel optional qt3-dev-tools-compat_3.3.4-8_i386.deb

-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.1 (GNU/Linux)
Comment: Signed by Christopher Martin <chrsmrtn@freeshell.org>

iD8DBQFDHzqZU+gWW+vtsysRAgn8AJ4oioLxhR9x+MVUy1pB4uHhJvtDXwCgjSC5
3w5lGvT1eQ21Px9bbMEznO4=
=cMZk
-----END PGP SIGNATURE-----



Reply to: